@@ -31,10 +31,14 @@ fi
 if [ -n "$NB_BIN" ]
 then
   echo "Stopping NetBird daemon"
-  netbird service stop || true
+  osascript -e 'quit app "Netbird UI"' 2> /dev/null || true
+  netbird service stop 2> /dev/null || true
 fi
 
 # start netbird daemon service
 echo "Starting Netbird daemon"
-netbird service install || true
-netbird service start || true
\ No newline at end of file
+netbird service install 2> /dev/null || true
+netbird service start || true
+
+# start app
+open /Applications/Netbird\ UI.app
\ No newline at end of file
